==> ideaIC-193.5662.46-sources.jar: org/jetbrains/idea/maven/execution/MavenRebuildAction.java <==
/*
 * Copyright 2000-2012 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.idea.maven.execution;

import com.intellij.execution.ExecutionBundle;
import com.intellij.execution.impl.ExecutionManagerImpl;
import com.intellij.execution.runners.ExecutionEnvironment;
import com.intellij.execution.runners.FakeRerunAction;
import com.intellij.execution.ui.RunContentDescriptor;
import com.intellij.icons.AllIcons;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.Presentation;
import com.intellij.openapi.util.text.StringUtil;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class MavenRebuildAction extends FakeRerunAction {

  private final ExecutionEnvironment myEnvironment;

  public MavenRebuildAction(ExecutionEnvironment environment) {
    myEnvironment = environment;
  }

  @Override
  public void update(@NotNull AnActionEvent event) {
    Presentation presentation = event.getPresentation();

    presentation.setText(ExecutionBundle.message("rerun.configuration.action.name",
                                                 StringUtil.escapeMnemonics(myEnvironment.getRunProfile().getName())));
    presentation.setIcon(
      ExecutionManagerImpl.isProcessRunning(myEnvironment.getContentToReuse()) ?
      AllIcons.Actions.Restart : AllIcons.Actions.Compile);
  }

  @Nullable
  @Override
  protected RunContentDescriptor getDescriptor(AnActionEvent event) {
    return myEnvironment.getContentToReuse();
  }

  @Nullable
  @Override
  protected ExecutionEnvironment getEnvironment(@NotNull AnActionEvent event) {
    return myEnvironment;
  }
}

==> ideaIC-211.7442.40-sources.jar: org/jetbrains/idea/maven/execution/MavenRebuildAction.java <==
/*
 * Copyright 2000-2012 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.idea.maven.execution;

import com.intellij.execution.ExecutionBundle;
import com.intellij.execution.impl.ExecutionManagerImpl;
import com.intellij.execution.runners.ExecutionEnvironment;
import com.intellij.execution.runners.FakeRerunAction;
import com.intellij.execution.ui.RunContentDescriptor;
import com.intellij.icons.AllIcons;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.Presentation;
import com.intellij.openapi.util.text.StringUtil;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class MavenRebuildAction extends FakeRerunAction {

  private final ExecutionEnvironment myEnvironment;

  public MavenRebuildAction(ExecutionEnvironment environment) {
    myEnvironment = environment;
  }

  @Override
  public void update(@NotNull AnActionEvent event) {
    Presentation presentation = event.getPresentation();

    presentation.setText(ExecutionBundle.messagePointer("rerun.configuration.action.name",
                                                 StringUtil.escapeMnemonics(myEnvironment.getRunProfile().getName())));
    presentation.setIcon(
      ExecutionManagerImpl.isProcessRunning(myEnvironment.getContentToReuse()) ?
      AllIcons.Actions.Restart : AllIcons.Actions.Compile);
  }

  @Nullable
  @Override
  protected RunContentDescriptor getDescriptor(AnActionEvent event) {
    return myEnvironment.getContentToReuse();
  }

  @Nullable
  @Override
  protected ExecutionEnvironment getEnvironment(@NotNull AnActionEvent event) {
    return myEnvironment;
  }
}
